#encoding:utf-8
class Rclone:
    '''模拟Rclone软件的类'''
    def __init__(self):
        self.__version = 'rclone 15.4.0'

    @property
    def version(self):
        return self.__version

    @version.setter
    def version(self,value):
        self.__version = value


if __name__ == '__main__':
    print(Rclone().version)


#encoding:utf-8
from distutils.core import setup

setup(
    name='WuSir',
    version='1.0',
    description='模拟测试代码发布。',
    author='wusir',
    author_email='whsoftware@gmail.com',
    py_modules=['rclone']
)